@@ -51,7 +51,9 @@
           r.using.full= get.rversion() 
           packageStartupMessage ("Loaded 'groundhog' (version:",packageVersion('groundhog'),  ") using R-" ,r.using.full) 
           packageStartupMessage (
-                  "The groundhog library is here: '",get.groundhog.folder(),"'.\nTo change its location: 'set.groundhog.folder(<path>)'\n"
+                  "Path to folder where downloaded packages are saved: '",get.groundhog.folder(),
+                  "'.\nTo change its location: 'set.groundhog.folder(<path>)'\n",
+                  "     >>> If you encounter errors using groundhog: http://groundhogR.com/troubleshooting"
                    )
         
     #2.2 check for update
@@ -74,9 +76,11 @@
     
         if (isTRUE(gv.cran.majmin > gv.using.majmin)) {
           packageStartupMessage(
+            "\n\n\n",
             "          OUTDATED GROUNDHOG\n",
-            "          You are using version  '" , groundhog.version_using, "\n",
-            "          The current version is '" , groundhog.version_cran, "'\n\n",
+            "            You are using version  '" , groundhog.version_using, "\n",
+            "            The current version is '" , groundhog.version_cran, "'\n\n",
+            "            You can read about the changes here: http://groundhogr.com/changelog\n\n",
             "Please update by running: \ninstall.packages('groundhog')"
             )
             }  #End mismatch in version
